import PaymentMethod from "../types/PaymentMethod";
import PaymentTotal from "../types/PaymentTotal";
import CreatePaymentConfig from "../types/CreatePaymentConfig";
import MidtransResponse from "../types/MidtransResponse";
export default class Payment {
    /**
     * Cek semua metode pembayaran yang tersedia
     * @returns Metode pembayaran yang tersedia
     */
    static getPaymentMethods(): Promise<Record<string, PaymentMethod> | Error>;
    /**
     * Mendapatkan total biaya yang harus dibayar
     * @param paymentMethod Metode pembayaran
     * @param amount Jumlah yang harus dibayar
     * @param is_payment_fee_by_supporter Apakah biaya admin dibayar oleh supporter
     * @returns Total biaya yang harus dibayar
     */
    static getTotalAmount(paymentMethod: string, amount: number, is_payment_fee_by_supporter?: boolean): Promise<PaymentTotal | Error>;
    static generateNewToken(): Promise<{
        csrf: string;
        cookie: string;
    } | Error>;
    /**
     * Membuat pembayaran
     * @param creatorId ID kreator
     * @param paymentMethod Metode pembayaran
     * @param amount Jumlah yang harus dibayar
     * @param config Konfigurasi pembayaran
     */
    static createPayment(creatorId: string, paymentMethod: string, amount: number, config?: CreatePaymentConfig): Promise<URL | MidtransResponse | Error>;
}
