"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const Cache_1 = __importDefault(require("../etc/Cache"));
class User {
    /**
     * Mendapatkan ID user dari page id
     * @param pageId Page id
     * @returns ID user
     */
    static getUserId(pageId) {
        return __awaiter(this, void 0, void 0, function* () {
            const cache = Cache_1.default.get(`userId_${pageId}`);
            if (cache)
                return cache.data;
            const req = yield axios_1.default
                .get(`https://trakteer.id/${pageId}`)
                .catch((e) => {
                throw new Error("User not found/Something not working");
            });
            const UserId = req.data.match(/(?<=creator-id=")(.*?)(?=\")/);
            if (req.status === 200 && !UserId)
                throw new Error("User not found/Invalid page id/Inactive page");
            if (!UserId[0])
                throw new Error("Invalid page id");
            Cache_1.default.set(`userId_${pageId}`, UserId[0], 60000);
            return UserId[0];
        });
    }
    /**
     * Mendapatkan detail user
     * @param userId ID user
     * @returns Detail user
     */
    static getUserDetails(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const cache = Cache_1.default.get(`userDetails_${userId}`);
            if (cache)
                return cache.data.data;
            const req = yield axios_1.default
                .get(`https://api.trakteer.id/v2/fe/creator/${userId}/summary`)
                .catch((e) => {
                if (e.status === 422)
                    throw new Error("ID user tidak valid");
                throw e;
            });
            if (req.status !== 200)
                throw new Error("ID user tidak valid");
            Cache_1.default.set(`userDetails_${userId}`, req.data, 60000);
            return req.data.data;
        });
    }
}
exports.default = User;
