"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.publicAPI = void 0;
const axios_1 = __importDefault(require("axios"));
const https_proxy_agent_1 = require("https-proxy-agent");
/**
 * Public API - Use the official API From trakteer
 * @see https://trakteer.id/manage/api-trakteer
 */
class publicAPI {
    constructor(apiKey, proxy, userAgent) {
        this.APIkey = apiKey;
        if (proxy)
            this.proxy = new https_proxy_agent_1.HttpsProxyAgent(proxy);
        this.userAgent = userAgent;
        this.axiosClient = axios_1.default.create({ httpsAgent: this.proxy });
    }
    /**
     * API ini digunakan untuk melihat jumlah unit trakteer-an yang telah diberikan oleh supporter (berdasarkan email) selama 30 hari terakhir.
     * @param email Supporter Email
     * @returns is unknown, please open issue if you have one example.
     */
    quantityGiven(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const req = yield axios_1.default.post("https://api.trakteer.id/v1/public/quantity-given", {
                email,
            }, {
                headers: {
                    Accept: "application/json",
                    "X-Requested-With": "XMLHttpRequest",
                    key: this.APIkey,
                    "User-Agent": this.userAgent,
                },
                httpsAgent: this.proxy,
            });
            if (req.data.status === "error")
                return new Error(req.data.message);
            return parseInt(req.data.result);
        });
    }
    /**
     * API ini digunakan untuk mendapatkan riwayat trakteer-an yang diberikan oleh supporter.
     * @param limit Number of records
     * @param page Current page in paginated records
     * @returns support history
     */
    supportHistory() {
        return __awaiter(this, arguments, void 0, function* (limit = 10, page = 1) {
            const req = yield this.axiosClient.get(`https://api.trakteer.id/v1/public/supports?limit=${limit}&page=${page}`, {
                headers: {
                    Accept: "application/json",
                    "X-Requested-With": "XMLHttpRequest",
                    key: this.APIkey,
                },
                httpsAgent: this.proxy,
            });
            return req.data;
        });
    }
    /**
     * API ini digunakan untuk melihat jumlah saldo yang dimiliki.
     * @returns Amount of balance
     */
    currentBalance() {
        return __awaiter(this, void 0, void 0, function* () {
            const req = yield this.axiosClient.get(`https://api.trakteer.id/v1/public/current-balance`, {
                headers: {
                    Accept: "application/json",
                    "X-Requested-With": "XMLHttpRequest",
                    key: this.APIkey,
                },
                httpsAgent: this.proxy,
            });
            if (!req.data || req.data.status !== "success")
                return Error(req.data.message);
            else
                return parseFloat(req.data.result);
        });
    }
    transactionHistory() {
        return __awaiter(this, arguments, void 0, function* (limit = 5, page = 1) {
            const req = yield this.axiosClient.get(`https://api.trakteer.id/v1/public/transactions?limit=${limit}&page=${page}`, {
                headers: {
                    Accept: "application/json",
                    "X-Requested-With": "XMLHttpRequest",
                    key: this.APIkey,
                },
                httpsAgent: this.proxy,
            });
            return req.data;
        });
    }
}
exports.publicAPI = publicAPI;
