"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const User_1 = __importDefault(require("../src/core/User"));
const Payment_1 = __importDefault(require("../src/core/Payment"));
const bun_test_1 = require("bun:test");
(0, bun_test_1.describe)("Test Payment", () => {
    (0, bun_test_1.test)("Get Payment Methods", () => __awaiter(void 0, void 0, void 0, function* () {
        const paymentMethods = yield Payment_1.default.getPaymentMethods();
        (0, bun_test_1.expect)(paymentMethods).not.toBeNull();
        (0, bun_test_1.expect)(paymentMethods).toBeObject();
    }));
    (0, bun_test_1.test)("Get Total Amount", () => __awaiter(void 0, void 0, void 0, function* () {
        const totalAmount = yield Payment_1.default.getTotalAmount("gopay", 100);
        (0, bun_test_1.expect)(totalAmount).not.toBe(Error);
        if (totalAmount instanceof Error)
            return;
        (0, bun_test_1.expect)(totalAmount).toBeObject();
        (0, bun_test_1.expect)(totalAmount).toContainKey("is_payment_fee_by_supporter");
        (0, bun_test_1.expect)(totalAmount).toContainKey("payment_method");
        (0, bun_test_1.expect)(totalAmount.payment_method).toBe("gopay");
        (0, bun_test_1.expect)(totalAmount).toContainKey("price");
        (0, bun_test_1.expect)(totalAmount.price).toBe(100);
        (0, bun_test_1.expect)(totalAmount).toContainKey("payment_fee");
        (0, bun_test_1.expect)(totalAmount).toContainKey("transfer_fee");
        (0, bun_test_1.expect)(totalAmount).toContainKey("total_price");
    }));
    (0, bun_test_1.test)("Get Total Amount (Error)", () => __awaiter(void 0, void 0, void 0, function* () {
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () { return Payment_1.default.getTotalAmount("notExist", 10); })).toThrowError();
    }));
});
(0, bun_test_1.describe)("Test createPayment", () => {
    (0, bun_test_1.test)("Create Midtrans Payment", () => {
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () {
            const userId = yield User_1.default.getUserId("trakteer.id");
            if (userId instanceof Error)
                return;
            const payment = yield Payment_1.default.createPayment(userId, "gopay", 100);
            return payment;
        }), "Gopay/Midtrans Fails").toBeObject();
    });
    (0, bun_test_1.test)("Create Xendit Payment", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        if (userId instanceof Error)
            return;
        const payment = yield Payment_1.default.createPayment(userId, "dana", 100);
        return payment;
    }));
});
(0, bun_test_1.describe)("Test createPayment (Error)", () => {
    (0, bun_test_1.test)("Create Payment (Error) - Minimum amount not met", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        if (userId instanceof Error)
            return;
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () { return Payment_1.default.createPayment(userId, "qris", 1); })).toThrowError();
    }));
    (0, bun_test_1.test)("Create Payment (Error) - OVO - Phone Number not set", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        if (userId instanceof Error)
            return;
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () { return Payment_1.default.createPayment(userId, "ovo", 100); })).toThrowError();
    }));
    (0, bun_test_1.test)("Create Payment (Error) - LinkAja - Phone Number not set", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        if (userId instanceof Error)
            return;
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () { return Payment_1.default.createPayment(userId, "linkaja", 100); })).toThrowError();
    }));
    (0, bun_test_1.test)("Create Payment (Error) - Jenius - Cashtag not set", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        if (userId instanceof Error)
            return;
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () { return Payment_1.default.createPayment(userId, "jenius", 100); })).toThrowError();
    }));
    (0, bun_test_1.test)("Create Payment (Error) - Jenius - Cashtag not valid", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        if (userId instanceof Error)
            return;
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () { return Payment_1.default.createPayment(userId, "jenius", 100, { cashtag: "notValid" }); })).toThrowError();
    }));
});
