"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bun_test_1 = require("bun:test");
const User_1 = __importDefault(require("../src/core/User"));
(0, bun_test_1.describe)("Get User Info", () => {
    (0, bun_test_1.test)("Get User ID from Page ID", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        (0, bun_test_1.expect)(userId).toBeString();
    }));
    (0, bun_test_1.test)("User not found (getUserId)", () => __awaiter(void 0, void 0, void 0, function* () {
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () {
            yield User_1.default.getUserId("thispagedefinitelynotexist123123123");
        })).toThrowError();
    }));
    (0, bun_test_1.test)("user not found (getUserDetails)", () => __awaiter(void 0, void 0, void 0, function* () {
        (0, bun_test_1.expect)(() => __awaiter(void 0, void 0, void 0, function* () {
            yield User_1.default.getUserDetails("sdsasdasd");
        })).toThrowError();
    }));
    (0, bun_test_1.test)("Get user details", () => __awaiter(void 0, void 0, void 0, function* () {
        const userId = yield User_1.default.getUserId("trakteer.id");
        if (userId instanceof Error)
            return;
        const userDetails = yield User_1.default.getUserDetails(userId);
        if (userDetails instanceof Error)
            return;
        (0, bun_test_1.expect)(userDetails).toBeObject();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("id");
        (0, bun_test_1.expect)(userDetails === null || userDetails === void 0 ? void 0 : userDetails.id).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("page");
        (0, bun_test_1.expect)(userDetails.page).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("username");
        (0, bun_test_1.expect)(userDetails.username).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("occupation");
        (0, bun_test_1.expect)(userDetails.occupation).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("cover_image");
        (0, bun_test_1.expect)(userDetails.cover_image).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("avatar");
        (0, bun_test_1.expect)(userDetails.avatar).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("category");
        (0, bun_test_1.expect)(userDetails.category).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("video_url");
        if (userDetails.video_url)
            (0, bun_test_1.expect)(userDetails.video_url).toBeString();
        else
            (0, bun_test_1.expect)(userDetails.video_url).toBeNull();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("summary");
        (0, bun_test_1.expect)(userDetails.summary).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("socials");
        (0, bun_test_1.expect)(userDetails.socials).toBeObject();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("follower_count");
        (0, bun_test_1.expect)(userDetails.follower_count).toBeString();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("is_following");
        (0, bun_test_1.expect)(userDetails.is_following).toBeBoolean();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("page_status");
        (0, bun_test_1.expect)(userDetails.page_status).toBeObject();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("is_live");
        (0, bun_test_1.expect)(userDetails.is_live).toBeBoolean();
        (0, bun_test_1.expect)(userDetails).toHaveProperty("stream_settings");
        (0, bun_test_1.expect)(userDetails.stream_settings).toBeObject();
        if (userDetails.active_goal) {
            (0, bun_test_1.expect)(userDetails).toHaveProperty("active_goal");
            (0, bun_test_1.expect)(userDetails.active_goal).toBeObject();
            (0, bun_test_1.expect)(userDetails.active_goal).toHaveProperty("active_goal");
        }
        (0, bun_test_1.expect)(userDetails).toHaveProperty("active_unit");
        (0, bun_test_1.expect)(userDetails.active_unit).toBeObject();
        (0, bun_test_1.expect)(userDetails.active_unit).toHaveProperty("data");
    }));
});
